@@ -33,6 +33,7 @@
 #include <memory.h>
 #include <unistd.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <math.h>
 #include <errno.h>
 
@@ -83,14 +84,22 @@ struct IPHeader {
 
 struct nethost {
   uint32 addr;
+  uint32 addrs[MAXPATH];	/* for multi paths byMin */
   int xmit;
   int returned;
   int sent;
   int up;
-  long long total;
+  long long var;/* variance, could be overflowed */
   int last;
   int best;
   int worst;
+  int avg;	/* average:  addByMin */
+  int gmean;	/* geometirc mean: addByMin */
+  int jitter;	/* current jitter, defined as t1-t0 addByMin */
+//int jbest;	/* min jitter, of cause it is 0, not needed */
+  int javg;	/* avg jitter */
+  int jworst;	/* max jitter */
+  int jinta;	/* estimated variance,? rfc1889's "Interarrival Jitter" */
   int transit;
   int saved[SAVED_PINGS];
   int saved_seq_offset;
@@ -119,11 +128,15 @@ int sendsock;
 int recvsock;
 struct sockaddr_in sourceaddress;
 struct sockaddr_in remoteaddress;
+
 static int batch_at = 0;
-
-
-extern int packetsize;
 static int numhosts = 10;
+extern int fstTTL;		/* initial hub(ttl) to ping byMin */
+extern int maxTTL;		/* last hub to ping byMin*/
+extern int packetsize;		/* packet size used by ping */
+extern int bitpattern;		/* packet bit pattern used by ping */
+extern int tos;			/* type of service set in ping packet*/
+
 
 /* return the number of microseconds to wait before sending the next
    ping */
@@ -178,7 +191,8 @@ int new_sequence(int index) {
 }
 
 /*  Attempt to find the host at a particular number of hops away  */
-void net_send_query(int index) {
+void net_send_query(int index) 
+{
   /*ok  char packet[sizeof(struct IPHeader) + sizeof(struct ICMPHeader)];*/
   char packet[MAXPACKET];
   struct IPHeader *ip;
@@ -190,35 +204,40 @@ void net_send_query(int index) {
 
   if ( packetsize < MINPACKET ) packetsize = MINPACKET;
   if ( packetsize > MAXPACKET ) packetsize = MAXPACKET;
-  memset(packet, 0, packetsize);
+
+  memset(packet, (unsigned char) abs(bitpattern), abs(packetsize));
 
   ip = (struct IPHeader *)packet;
   icmp = (struct ICMPHeader *)(packet + sizeof(struct IPHeader));
 
   ip->version = 0x45;
-  ip->tos = 0;
-  ip->len = BSDfix ? packetsize: htons (packetsize);
+  ip->tos = tos;
+  ip->len = BSDfix ? abs(packetsize): htons (abs(packetsize));
   ip->id = 0;
-  ip->frag = 0;
+  ip->frag = 0;    /* 1, if want to find mtu size? Min */
   ip->ttl = index + 1;
   ip->protocol = IPPROTO_ICMP;
+  ip->check = 0;
+
   /* BSD needs the source address here, Linux & others do not... */
   ip->saddr = saddr_correction(sourceaddress.sin_addr.s_addr);
   ip->daddr = remoteaddress.sin_addr.s_addr;
 
-  icmp->type = ICMP_ECHO;
-  icmp->id = getpid();
+  icmp->type     = ICMP_ECHO;
+  icmp->code     = 0;
+  icmp->checksum = 0;
+  icmp->id       = getpid();
   icmp->sequence = new_sequence(index);
 
-  icmp->checksum = checksum(icmp, packetsize - sizeof(struct IPHeader));
-  ip->check = checksum(ip, packetsize);
+  icmp->checksum = checksum(icmp, abs(packetsize) - sizeof(struct IPHeader));
+  ip->check = checksum(ip, abs(packetsize));
 
   gettimeofday(&sequence[icmp->sequence].time, NULL);
-  rv = sendto(sendsock, packet, packetsize, 0, 
-	 (struct sockaddr *)&remoteaddress, sizeof(remoteaddress));
+  rv = sendto(sendsock, packet, abs(packetsize), 0, 
+	      (struct sockaddr *)&remoteaddress, sizeof(remoteaddress));
   if (first && (rv < 0) && (errno == EINVAL)) {
-    ip->len = packetsize;
-    rv = sendto(sendsock, packet, packetsize, 0, 
+    ip->len = abs (packetsize);
+    rv = sendto(sendsock, packet, abs(packetsize), 0, 
 		(struct sockaddr *)&remoteaddress, sizeof(remoteaddress));
     if (rv >= 0) {
       fprintf (stderr, "You've got a broken (FreeBSD?) system\n");
@@ -233,6 +252,9 @@ void net_send_query(int index) {
 void net_process_ping(int seq, uint32 addr, struct timeval now) {
   int index;
   int totusec;
+  int oldavg;	/* usedByMin */
+  int oldjavg;	/* usedByMin */
+  int i;	/* usedByMin */
 
   if(seq < 0 || seq >= MaxSequence)
     return;
@@ -245,22 +267,69 @@ void net_process_ping(int seq, uint32 addr, struct timeval now) {
 
   totusec = (now.tv_sec  - sequence[seq].time.tv_sec ) * 1000000 +
             (now.tv_usec - sequence[seq].time.tv_usec);
+  /* impossible? if( totusec < 0 ) totusec = 0 */;
 
   if(host[index].addr == 0) {
-    host[index].addr = addr;
+    host[index].addr = addr;	// should be out of if as addr can change
     display_rawhost(index, host[index].addr);
-  }
-  if(host[index].returned <= 0) {
-    host[index].best = host[index].worst = totusec;
-  }
-  host[index].last = totusec;
-  if(totusec < host[index].best)
-    host[index].best = totusec;
-  if(totusec > host[index].worst)
-    host[index].worst = totusec;
 
-  host[index].total += totusec;
+  /* multi paths by Min */
+    host[index].addrs[0] = addr;
+  } else {
+    for( i=0; i<MAXPATH; ) {
+      if( host[index].addrs[i] == addr || host[index].addrs[i] == 0 ) break;
+      i++;
+    }
+    if( host[index].addrs[i] != addr && i<MAXPATH ) {
+      host[index].addrs[i] = addr;
+    }
+  /* end multi paths */
+  }
+
+  host[index].jitter = totusec - host[index].last;
+  if( host[index].jitter < 0 ) host[index].jitter = - host[index].jitter;
+  host[index].last = totusec;
+
+  if(host[index].returned < 1) {
+    host[index].best = host[index].worst = host[index].gmean = totusec;
+    host[index].avg  = host[index].var  = 0;
+
+    host[index].jitter = host[index].jworst = host[index].jinta= 0;
+  }
+
+  /* some time best can be too good to be true, experienced 
+   * at least in linux 2.4.x.
+   *  safe guard 1) best[index]>=best[index-1] if index>0
+   *             2) best >= average-20,000 usec (good number?)
+   *  Min
+  if( index > 0 ) {
+    if(totusec < host[index].best &&
+       totusec>= host[index-1].best ) host[index].best  = totusec;
+  } else {
+    if(totusec < host[index].best ) host[index].best  = totusec;
+  }
+   */
+  if(totusec < host[index].best ) host[index].best  = totusec;
+  if(totusec > host[index].worst) host[index].worst = totusec;
+
+  if(host[index].jitter > host[index].jworst)
+	host[index].jworst = host[index].jitter;
+
   host[index].returned++;
+  /* begin addByMin do more stats */
+  oldavg = host[index].avg;
+  host[index].avg += (totusec - oldavg +.0) / host[index].returned;
+  host[index].var += (totusec - oldavg +.0) * (totusec - host[index].avg);
+
+  oldjavg = host[index].javg;
+  host[index].javg += (host[index].jitter - oldjavg) / host[index].returned;
+  /* below algorithm is from rfc1889, A.8 */
+  host[index].jinta += host[index].jitter - ((host[index].jinta + 8) >> 4);
+
+  if ( host[index].returned > 1 )
+  host[index].gmean = pow( (double) host[index].gmean, (host[index].returned-1.0)/host[index].returned )
+			* pow( (double) totusec, 1.0/host[index].returned );
+  /* end addByMin*/
   host[index].sent = 0;
   host[index].up = 1;
   host[index].transit = 0;
@@ -273,7 +342,7 @@ void net_process_ping(int seq, uint32 addr, struct timeval now) {
     now we just need to read it, see if it is for us, and if it is a reply 
     to something we sent, then call net_process_ping()  */
 void net_process_return() {
-  char packet[2048];
+  char packet[MAXPACKET];
   struct sockaddr_in fromaddr;
   int fromaddrsize;
   int num;
@@ -283,7 +352,7 @@ void net_process_return() {
   gettimeofday(&now, NULL);
 
   fromaddrsize = sizeof(fromaddr);
-  num = recvfrom(recvsock, packet, 2048, 0, 
+  num = recvfrom(recvsock, packet, MAXPACKET, 0, 
 		 (struct sockaddr *)&fromaddr, &fromaddrsize);
 
   if(num < sizeof(struct IPHeader) + sizeof(struct ICMPHeader))
@@ -312,39 +381,72 @@ void net_process_return() {
 int net_addr(int at) {
   return ntohl(host[at].addr);
 }
-
-int net_percent(int at) {
-  if((host[at].xmit - host[at].transit) == 0) 
-    return 0;
-
-  return 100 - (100 * host[at].returned / (host[at].xmit - host[at].transit));
+int net_addrs(int at, int i) {
+  return ntohl(host[at].addrs[i]);
 }
 
-int net_last(int at) {
-  return host[at].last;
+
+
+int net_loss(int at) 
+{
+  if((host[at].xmit - host[at].transit) == 0) return 0;
+  /* times extra 1000 */
+  return 1000*(100 - (100.0 * host[at].returned / (host[at].xmit - host[at].transit)) );
 }
 
-int net_best(int at) {
-  return host[at].best;
+int net_drop(int at) 
+{
+  return (host[at].xmit - host[at].transit) - host[at].returned;
 }
 
-int net_worst(int at) {
-  return host[at].worst;
+int net_last(int at) 
+{
+  return (host[at].last);
 }
 
-int net_avg(int at) {
-  if(host[at].returned == 0)
-    return 0;
-
-  return host[at].total / host[at].returned;
+int net_best(int at) 
+{
+  return (host[at].best);
 }
 
-int net_max() {
+int net_worst(int at) 
+{
+  return (host[at].worst);
+}
+
+int net_avg(int at) 
+{
+  return (host[at].avg);
+}
+int net_gmean(int at) 
+{
+  return (host[at].gmean);
+}
+int net_stdev(int at) 
+{
+  if( host[at].returned > 1 ) {
+    return ( sqrt( host[at].var/(host[at].returned -1.0) ) );
+  } else {
+    return( 0 );
+  }
+}
+/* jitter stuff */
+int net_jitter(int at) { return (host[at].jitter); }
+int net_jworst(int at) { return (host[at].jworst); }
+int net_javg(int at) { return (host[at].javg); }
+int net_jinta(int at) { return (host[at].jinta); }
+/* end jitter */
+
+
+int net_max() 
+{
   int at;
   int max;
 
   max = 0;
-  for(at = 0; at < MaxHost-2; at++) {
+  // replacedByMin
+  // for(at = 0; at < MaxHost-2; at++) {
+  for(at = 0; at < maxTTL-1; at++) {
     if(host[at].addr == remoteaddress.sin_addr.s_addr) {
       return at + 1;
     } else if(host[at].addr != 0) {
@@ -355,25 +457,37 @@ int net_max() {
   return max;
 }
 
+/* add by Min (wonder its named net_min;-)) because of ttl stuff */
+int net_min () 
+{
+  return ( fstTTL - 1 );
+}
+
 
 /* Added by Brian Casey December 1997 bcasey@imagiware.com*/
-int net_returned(int at) { 
-   return host[at].returned;
+int net_returned(int at) 
+{ 
+  return host[at].returned;
 }
-int net_xmit(int at) { 
-   return host[at].xmit;
-}
-int net_transit(int at) { 
-   return host[at].transit;
+int net_xmit(int at) 
+{ 
+  return host[at].xmit;
 }
 
-int net_up(int at) { 
+int net_transit(int at) 
+{ 
+  return host[at].transit;
+}
+
+int net_up(int at) 
+{
    return host[at].up;
 }
 
-void net_end_transit() {
+void net_end_transit() 
+{
   int at;
-
+  
   for(at = 0; at < MaxHost; at++) {
     host[at].transit = 0;
   }
@@ -381,25 +495,40 @@ void net_end_transit() {
 
 
 
-int net_send_batch() {
-  int n_unknown, i;
+int net_send_batch() 
+{
+  int n_unknown=0, i;
 
+  /* randomized packet size and/or bit pattern if packetsize<0 and/or 
+     bitpattern<0.  abs(packetsize) and/or abs(bitpattern) will be used 
+  */
+  if( batch_at < fstTTL ) {
+    if( packetsize < 0 ) {
+      packetsize = 
+	- (int)(MINPACKET + (MAXPACKET-MINPACKET)*(rand()/(RAND_MAX+0.1)));
+    }
+    if( bitpattern < 0 ) {
+      bitpattern = - (int)(256 + 255*(rand()/(RAND_MAX+0.1)));
+    }
+  }
   net_send_query(batch_at);
 
-  n_unknown = 0;
-
-  for (i=0;i<batch_at;i++) {
+  for (i=fstTTL-1;i<batch_at;i++) {
     if (host[i].addr == 0)
       n_unknown++;
-    if (host[i].addr == remoteaddress.sin_addr.s_addr)
-      n_unknown = 100; /* Make sure we drop into "we should restart" */
-  }
 
-  if ((host[batch_at].addr == remoteaddress.sin_addr.s_addr) ||
+    if ((host[i].addr == remoteaddress.sin_addr.s_addr) ||
+        (host[i].addr == host[batch_at].addr))
+      n_unknown = MaxHost; /* Make sure we drop into "we should restart" */
+  }
+  if (	// success in reaching target
+      (host[batch_at].addr == remoteaddress.sin_addr.s_addr) ||
+      // fail in consecuitive MAX_UNKNOWN_HOSTS (firewall?)
       (n_unknown > MAX_UNKNOWN_HOSTS) ||
-      (batch_at >= MaxHost-2)) {
+      // or reach limit 
+      (batch_at >= maxTTL-1)) {
     numhosts = batch_at+1;
-    batch_at = 0;
+    batch_at = fstTTL - 1;
     return 1;
   }
 
@@ -408,7 +537,8 @@ int net_send_batch() {
 }
 
 
-int net_preopen() {
+int net_preopen() 
+{
   int trueopt = 1;
 
   sendsock = socket(AF_INET, SOCK_RAW, IPPROTO_RAW);
@@ -432,7 +562,8 @@ int net_preopen() {
   return 0;
 }
  
-int net_open(int addr) {
+int net_open(int addr) 
+{
   net_reset();
 
   remoteaddress.sin_family = AF_INET;
@@ -441,7 +572,8 @@ int net_open(int addr) {
   return 0;
 }
 
-void net_reopen(int addr) {
+void net_reopen(int addr) 
+{
   int at;
 
   for(at = 0; at < MaxHost; at++) {
@@ -455,11 +587,12 @@ void net_reopen(int addr) {
   net_send_batch();
 }
 
-void net_reset() {
+void net_reset() 
+{
   int at;
   int i;
 
-  batch_at = 0;
+  batch_at = fstTTL - 1;	/* above replacedByMin */
   numhosts = 10;
 
   for(at = 0; at < MaxHost; at++) {
@@ -468,9 +601,16 @@ void net_reset() {
     host[at].returned = 0;
     host[at].sent = 0;
     host[at].up = 0;
-    host[at].total = 0;
+    host[at].last = 0;
+    host[at].avg  = 0;
     host[at].best = 0;
     host[at].worst = 0;
+    host[at].gmean = 0;
+    host[at].var = 0;
+    host[at].jitter = 0;
+    host[at].javg = 0;
+    host[at].jworst = 0;
+    host[at].jinta = 0;
     for (i=0; i<SAVED_PINGS; i++) {
       host[at].saved[i] = -2;	/* unsent */
     }
@@ -484,18 +624,21 @@ void net_reset() {
   gettimeofday(&reset, NULL);
 }
 
-void net_close() {
+void net_close() 
+{
   close(sendsock);
   close(recvsock);
 }
 
-int net_waitfd() {
+int net_waitfd() 
+{
   return recvsock;
 }
 
 
-int* net_saved_pings(int at) {
-	return host[at].saved;
+int* net_saved_pings(int at) 
+{
+  return host[at].saved;
 }
 
 void net_save_increment() 
@@ -508,17 +651,19 @@ void net_save_increment()
   }
 }
 
-void net_save_xmit(int at) {
+void net_save_xmit(int at) 
+{
   if (host[at].saved[SAVED_PINGS-1] != -2) 
     net_save_increment();
   host[at].saved[SAVED_PINGS-1] = -1;
 }
 
-void net_save_return(int at, int seq, int ms) {
-	int idx;
-	idx = seq - host[at].saved_seq_offset;
-	if (idx < 0 || idx > SAVED_PINGS) {
-	  return;
-	}
-	host[at].saved[idx] = ms;
+void net_save_return(int at, int seq, int ms) 
+{
+  int idx;
+  idx = seq - host[at].saved_seq_offset;
+  if (idx < 0 || idx > SAVED_PINGS) {
+    return;
+  }
+  host[at].saved[idx] = ms;
 }
